[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- tlslite.constants.AlertDescription
- tlslite.constants.AlertLevel
- tlslite.integration.asyncstatemachine.AsyncStateMachine: This is an abstract class that's used to integrate TLS Lite with asyncore and Twisted.
  - tlslite.integration.tlsasyncdispatchermixin.TLSAsyncDispatcherMixIn: This class can be "mixed in" with an `asyncore.dispatcher` to add TLS support.
- SocketServer.BaseRequestHandler: Base class for request handler classes.
  - SocketServer.StreamRequestHandler: Define self.rfile and self.wfile for stream sockets.
    - BaseHTTPServer.BaseHTTPRequestHandler: HTTP request handler base class.
      - SimpleXMLRPCServer.SimpleXMLRPCRequestHandler: Simple XML-RPC request handler class.
        - tlslite.integration.xmlrpcserver.TLSXMLRPCRequestHandler: XMLRPCRequestHandler using TLS
- SocketServer.BaseServer: Base class for server classes.
  - SocketServer.TCPServer: Base class for various socket-based server classes.
    - SimpleXMLRPCServer.SimpleXMLRPCServer: Simple XML-RPC server.
      - tlslite.integration.xmlrpcserver.TLSXMLRPCServer: Simple XML-RPC server using TLS
        - tlslite.integration.xmlrpcserver.MultiPathTLSXMLRPCServer: Multipath XML-RPC Server using TLS
- tlslite.constants.CertificateType
- tlslite.constants.CipherSuite
- tlslite.constants.ClientCertificateType
- tlslite.constants.ContentType
- tlslite.constants.ExtensionType
- tlslite.constants.Fault
- httplib.HTTPConnection
  - tlslite.integration.httptlsconnection.HTTPTLSConnection: This class extends `httplib.HTTPConnection` to support TLS.
- httplib.HTTPResponse
- tlslite.constants.HandshakeType
- imaplib.IMAP4: IMAP4 client class.
  - tlslite.integration.imap4_tls.IMAP4_TLS: This class extends `imaplib.IMAP4` with TLS support.
- rfc822.Message: Represents a single RFC 2822-compliant message.
  - mimetools.Message: A derived class of rfc822.Message that knows about MIME headers and contains some hooks for decoding encoded and multipart messages.
- tlslite.constants.NameType
- poplib.POP3: This class supports both the minimal and optional command sets.
  - tlslite.integration.pop3_tls.POP3_TLS: This class extends `poplib.POP3` with TLS support.
- smtplib.SMTP: This class manages a connection to an SMTP or ESMTP server.
  - tlslite.integration.smtp_tls.SMTP_TLS: This class extends `smtplib.SMTP` with TLS support.
- SimpleXMLRPCServer.SimpleXMLRPCDispatcher: Mix-in class that dispatches XML-RPC requests.
  - SimpleXMLRPCServer.SimpleXMLRPCServer: Simple XML-RPC server.
    - tlslite.integration.xmlrpcserver.TLSXMLRPCServer: Simple XML-RPC server using TLS
      - tlslite.integration.xmlrpcserver.MultiPathTLSXMLRPCServer: Multipath XML-RPC Server using TLS
- tlslite.integration.tlssocketservermixin.TLSSocketServerMixIn: This class can be mixed in with any `SocketServer.TCPServer` to add TLS support.
  - tlslite.integration.xmlrpcserver.TLSXMLRPCServer: Simple XML-RPC server using TLS
    - tlslite.integration.xmlrpcserver.MultiPathTLSXMLRPCServer: Multipath XML-RPC Server using TLS
- xmlrpclib.Transport: Handles an HTTP transaction to an XML-RPC server.
  - tlslite.integration.xmlrpctransport.XMLRPCTransport: Handles an HTTPS transaction to an XML-RPC server.
- object: The most base type
  - tlslite.utils.aes.AES
    - tlslite.utils.python_aes.Python_AES
  - tlslite.utils.asn1parser.ASN1Parser
  - tlslite.messages.Alert
  - tlslite.messages.ApplicationData
  - tlslite.basedb.BaseDB
    - tlslite.verifierdb.VerifierDB: This class represent an in-memory or on-disk database of SRP password verifiers.
  - exceptions.BaseException: Common base class for all exceptions
    - exceptions.Exception: Common base class for all non-exit exceptions.
      - tlslite.messages.BadNextProtos
      - exceptions.StandardError: Base class for all standard Python exceptions that do not represent interpreter exiting.
        - exceptions.EnvironmentError: Base class for I/O related errors.
          - exceptions.IOError: I/O operation failed.
            - socket.error
              - tlslite.errors.TLSClosedConnectionError: An attempt was made to use the connection after it was closed.
      - tlslite.errors.TLSError: Base class for all TLS Lite exceptions.
        - tlslite.errors.TLSAbruptCloseError: The socket was closed without a proper TLS shutdown.
        - tlslite.errors.TLSAlert: A TLS alert has been signalled.
          - tlslite.errors.TLSLocalAlert: A TLS alert has been signalled by the local implementation.
          - tlslite.errors.TLSRemoteAlert: A TLS alert has been signalled by the remote implementation.
        - tlslite.errors.TLSAuthenticationError: The handshake succeeded, but the other party's authentication was inadequate.
          - tlslite.errors.TLSAuthenticationTypeError: The Checker was expecting the other party to authenticate with a different type of certificate chain.
          - tlslite.errors.TLSAuthorizationError: The Checker was expecting the other party to authenticate with a certificate chain that has a different authorization.
          - tlslite.errors.TLSFingerprintError: The Checker was expecting the other party to authenticate with a certificate chain that matches a different fingerprint.
          - tlslite.errors.TLSNoAuthenticationError: The Checker was expecting the other party to authenticate with a certificate chain, but this did not occur.
          - tlslite.errors.TLSValidationError: The Checker has determined that the other party's certificate chain is invalid.
        - tlslite.errors.TLSClosedConnectionError: An attempt was made to use the connection after it was closed.
        - tlslite.errors.TLSFaultError: The other party responded incorrectly to an induced fault.
        - tlslite.errors.TLSUnsupportedError: The implementation doesn't support the requested (or required) capabilities.
      - imaplib.IMAP4.error
        - imaplib.IMAP4.abort
          - imaplib.IMAP4.readonly
  - tlslite.messages.ChangeCipherSpec
  - tlslite.checker.Checker: This class is passed to a handshake function to check the other party's certificate chain.
  - tlslite.integration.clienthelper.ClientHelper: This is a helper class used to integrate TLS Lite with various TLS clients (e.g.
    - tlslite.integration.httptlsconnection.HTTPTLSConnection: This class extends `httplib.HTTPConnection` to support TLS.
    - tlslite.integration.imap4_tls.IMAP4_TLS: This class extends `imaplib.IMAP4` with TLS support.
    - tlslite.integration.pop3_tls.POP3_TLS: This class extends `poplib.POP3` with TLS support.
    - tlslite.integration.xmlrpctransport.XMLRPCTransport: Handles an HTTPS transaction to an XML-RPC server.
  - tlslite.messages.HandshakeMsg
    - tlslite.messages.Certificate
    - tlslite.messages.CertificateRequest
    - tlslite.messages.CertificateVerify
    - tlslite.messages.ClientHello
    - tlslite.messages.ClientKeyExchange
    - tlslite.messages.Finished
    - tlslite.messages.NextProtocol
    - tlslite.messages.ServerHello
    - tlslite.messages.ServerHelloDone
    - tlslite.messages.ServerKeyExchange
  - tlslite.handshakesettings.HandshakeSettings: This class encapsulates various parameters that can be used with a TLS handshake.
  - tlslite.mathtls.MAC_SSL
  - tlslite.utils.codec.Parser
  - tlslite.utils.rc4.RC4
    - tlslite.utils.python_rc4.Python_RC4
  - tlslite.utils.rsakey.RSAKey: This is an abstract base class for RSA keys.
    - tlslite.utils.python_rsakey.Python_RSAKey
  - tlslite.messages.RecordHeader2
  - tlslite.messages.RecordHeader3
  - tlslite.session.Session: This class represents a TLS session.
  - tlslite.sessioncache.SessionCache: This class is used by the server to cache TLS sessions.
  - tlslite.tlsrecordlayer.TLSRecordLayer: This class handles data transmission for a TLS connection.
    - tlslite.tlsconnection.TLSConnection: This class wraps a socket and provides TLS handshaking and data transfer.
  - tlslite.utils.tripledes.TripleDES
  - tlslite.utils.codec.Writer
  - tlslite.x509.X509: This class represents an X.509 certificate.
  - tlslite.x509certchain.X509CertChain: This class represents a chain of X.509 certificates.
  - tlslite.tlsrecordlayer._ConnectionState
- tlslite.utils.rijndael.rijndael